@@ -1,12 +1,14 @@
-from .mytree import Mytree, meta_leaves, meta
-from .param import param_field
 from .bijectors import Identity, Softplus
+from .mytree import Mytree, meta, meta_flatten, meta_leaves, meta_map
+from .param import param_field
 
 __all__ = [
     "Mytree",
     "meta_leaves",
+    "meta_flatten",
+    "meta_map",
     "meta",
     "param_field",
     "Identity",
     "Softplus",
-]
\ No newline at end of file
+]
