@@ -2,19 +2,17 @@ from __future__ import annotations
 
 __all__ = ["Bijector", "Identity", "Softplus"]
 
-import importlib
-import jax.numpy as jnp
-from typing import Callable
 from dataclasses import dataclass
+from typing import Callable
+
+import jax.numpy as jnp
 from simple_pytree import Pytree, static_field
 
+
 @dataclass
 class Bijector(Pytree):
-    forward: Callable = static_field()
-    inverse: Callable = static_field()
-
-def __init__(self, forward: Callable, inverse: Callable) -> None:
-    """Initialise the bijector.
+    """
+    Create a bijector.
 
     Args:
         forward(Callable): The forward transformation.
@@ -23,13 +21,14 @@ def __init__(self, forward: Callable, inverse: Callable) -> None:
     Returns:
         Bijector: A bijector.
     """
-    self.forward = forward
-    self.inverse = inverse
+
+    forward: Callable = static_field()
+    inverse: Callable = static_field()
 
 
 Identity = Bijector(forward=lambda x: x, inverse=lambda x: x)
 
 Softplus = Bijector(
-    forward=lambda x: jnp.log(1 + jnp.exp(x)),
+    forward=lambda x: jnp.log(1.0 + jnp.exp(x)),
     inverse=lambda x: jnp.log(jnp.exp(x) - 1.0),
 )
